# skyfire-sdk
The Skyfire API is designed to allow agents to interact with the Skyfire platform to enable autonomous payments.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 0.6.5
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import skyfire_sdk
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import skyfire_sdk
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import skyfire_sdk
from skyfire_sdk.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.skyfire.xyz
# See configuration.py for a list of all supported configuration parameters.
configuration = skyfire_sdk.Configuration(
    host = "https://api.skyfire.xyz"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with skyfire_sdk.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = skyfire_sdk.APINinjaApi(api_client)
    symbol = 'LTCBTC' # str | Cryptocurrency symbol.

    try:
        # Crypto Price
        api_response = api_instance.crypto_price(symbol)
        print("The response of APINinjaApi->crypto_price:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling APINinjaApi->crypto_price: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.skyfire.xyz*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*APINinjaApi* | [**crypto_price**](docs/APINinjaApi.md#crypto_price) | **GET** /proxy/api-ninja/v1/cryptoprice | Crypto Price
*APINinjaApi* | [**dns_lookup**](docs/APINinjaApi.md#dns_lookup) | **GET** /proxy/api-ninja/v1/dnslookup | DNS Lookup
*APINinjaApi* | [**ip_lookup**](docs/APINinjaApi.md#ip_lookup) | **GET** /proxy/api-ninja/v1/iplookup | IP Lookup
*APINinjaApi* | [**stock_price**](docs/APINinjaApi.md#stock_price) | **GET** /proxy/api-ninja/v1/stockprice | Stock Price
*APINinjaApi* | [**weather**](docs/APINinjaApi.md#weather) | **GET** /proxy/api-ninja/v1/weather | Weather
*ChatApi* | [**create_open_ai_chat_completion**](docs/ChatApi.md#create_open_ai_chat_completion) | **POST** /proxy/openai/v1/chat/completions | Creates a model response for the given chat conversation.
*ChatApi* | [**create_open_router_chat_completion**](docs/ChatApi.md#create_open_router_chat_completion) | **POST** /proxy/openrouter/v1/chat/completions | Creates a model response for the given chat conversation.
*ChatApi* | [**create_perplexity_chat_completion**](docs/ChatApi.md#create_perplexity_chat_completion) | **POST** /proxy/perplexity/chat/completions | Creates a model response for the given chat conversation.
*FinancialDatasetsAIApi* | [**balance_sheets**](docs/FinancialDatasetsAIApi.md#balance_sheets) | **GET** /proxy/financial-datasets-ai/financials/balance-sheets | Balance Sheets
*FinancialDatasetsAIApi* | [**cash_flow_statements**](docs/FinancialDatasetsAIApi.md#cash_flow_statements) | **GET** /proxy/financial-datasets-ai/financials/cash-flow-statements | Cash Flow Statements
*FinancialDatasetsAIApi* | [**income_statements**](docs/FinancialDatasetsAIApi.md#income_statements) | **GET** /proxy/financial-datasets-ai/financials/income-statements | Income Statements
*GiftCardApi* | [**gift_card_order**](docs/GiftCardApi.md#gift_card_order) | **POST** /v1/receivers/reloadly/gift-card | 
*ToolkitApi* | [**send_email**](docs/ToolkitApi.md#send_email) | **POST** /v1/receivers/toolkit/send-email | 
*VetricApi* | [**facebook_event_search**](docs/VetricApi.md#facebook_event_search) | **GET** /v1/receivers/vetric/facebook/event-search | 
*VetricApi* | [**facebook_marketplace_search**](docs/VetricApi.md#facebook_marketplace_search) | **GET** /v1/receivers/vetric/facebook/marketplace-search | 
*VetricApi* | [**facebook_people_search**](docs/VetricApi.md#facebook_people_search) | **GET** /v1/receivers/vetric/facebook/people-search | 
*VetricApi* | [**instagram_location_map**](docs/VetricApi.md#instagram_location_map) | **GET** /v1/receivers/vetric/instagram/location-map | 
*VetricApi* | [**instagram_people_search**](docs/VetricApi.md#instagram_people_search) | **GET** /v1/receivers/vetric/instagram/people-search | 
*VetricApi* | [**linked_in_company_people_search**](docs/VetricApi.md#linked_in_company_people_search) | **GET** /v1/receivers/vetric/linkedin/company/people | 
*VetricApi* | [**linked_in_job_search**](docs/VetricApi.md#linked_in_job_search) | **GET** /v1/receivers/vetric/linkedin/job-search | 
*VetricApi* | [**linked_in_people_search**](docs/VetricApi.md#linked_in_people_search) | **GET** /v1/receivers/vetric/linkedin/people-search | 
*VetricApi* | [**twitter_top**](docs/VetricApi.md#twitter_top) | **GET** /v1/receivers/vetric/twitter/top | 
*WalletManagementApi* | [**delete_wallet**](docs/WalletManagementApi.md#delete_wallet) | **GET** /v1/wallet/delete/{walletId} | 
*WalletManagementApi* | [**get_claim_by_reference_id**](docs/WalletManagementApi.md#get_claim_by_reference_id) | **GET** /v1/wallet/claimByReferenceId/{referenceId} | 
*WalletManagementApi* | [**get_claims_for_user**](docs/WalletManagementApi.md#get_claims_for_user) | **GET** /v1/wallet/claims | 
*WalletManagementApi* | [**get_wallet_balance_by_address**](docs/WalletManagementApi.md#get_wallet_balance_by_address) | **GET** /v1/wallet/balance/{network} | 
*WalletManagementApi* | [**get_wallet_balance_for_user**](docs/WalletManagementApi.md#get_wallet_balance_for_user) | **GET** /v1/wallet/balance | 
*WalletManagementApi* | [**update_wallet**](docs/WalletManagementApi.md#update_wallet) | **POST** /v1/wallet/update | 
*WalletManagementApi* | [**wallet**](docs/WalletManagementApi.md#wallet) | **GET** /v1/wallet | 


## Documentation For Models

 - [APINinjaCryptoPriceResponse](docs/APINinjaCryptoPriceResponse.md)
 - [APINinjaDNSLookupResponse](docs/APINinjaDNSLookupResponse.md)
 - [APINinjaDNSRecord](docs/APINinjaDNSRecord.md)
 - [APINinjaIPLookupResponse](docs/APINinjaIPLookupResponse.md)
 - [APINinjaStockResponse](docs/APINinjaStockResponse.md)
 - [APINinjaWeatherResponse](docs/APINinjaWeatherResponse.md)
 - [BalanceSheet](docs/BalanceSheet.md)
 - [BalanceSheets200Response](docs/BalanceSheets200Response.md)
 - [CashFlowStatement](docs/CashFlowStatement.md)
 - [CashFlowStatements200Response](docs/CashFlowStatements200Response.md)
 - [ChatCompletionMessageToolCall](docs/ChatCompletionMessageToolCall.md)
 - [ChatCompletionMessageToolCallFunction](docs/ChatCompletionMessageToolCallFunction.md)
 - [ChatCompletionRequestMessage](docs/ChatCompletionRequestMessage.md)
 - [ChatCompletionResponseMessage](docs/ChatCompletionResponseMessage.md)
 - [ChatCompletionResponseMessageFunctionCall](docs/ChatCompletionResponseMessageFunctionCall.md)
 - [ChatCompletionStreamOptions](docs/ChatCompletionStreamOptions.md)
 - [ChatCompletionTokenLogprob](docs/ChatCompletionTokenLogprob.md)
 - [ChatCompletionTokenLogprobTopLogprobsInner](docs/ChatCompletionTokenLogprobTopLogprobsInner.md)
 - [ChatCompletionTool](docs/ChatCompletionTool.md)
 - [Claim](docs/Claim.md)
 - [ClaimsResponse](docs/ClaimsResponse.md)
 - [CompletionUsage](docs/CompletionUsage.md)
 - [CreateChatCompletionRequest](docs/CreateChatCompletionRequest.md)
 - [CreateChatCompletionRequestResponseFormat](docs/CreateChatCompletionRequestResponseFormat.md)
 - [CreateChatCompletionResponse](docs/CreateChatCompletionResponse.md)
 - [CreateChatCompletionResponseChoicesInner](docs/CreateChatCompletionResponseChoicesInner.md)
 - [CreateChatCompletionResponseChoicesInnerLogprobs](docs/CreateChatCompletionResponseChoicesInnerLogprobs.md)
 - [EmailDumpRequest](docs/EmailDumpRequest.md)
 - [ErrorCode](docs/ErrorCode.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [EthNetworkType](docs/EthNetworkType.md)
 - [FunctionObject](docs/FunctionObject.md)
 - [GiftCardOrderRequest](docs/GiftCardOrderRequest.md)
 - [IncomeStatementsResponseInner](docs/IncomeStatementsResponseInner.md)
 - [OpenRouterCreateChatCompletionRequest](docs/OpenRouterCreateChatCompletionRequest.md)
 - [PaginationMeta](docs/PaginationMeta.md)
 - [PerplexityCreateChatCompletionRequest](docs/PerplexityCreateChatCompletionRequest.md)
 - [ReloadlyGiftCardResponse](docs/ReloadlyGiftCardResponse.md)
 - [ReloadlyGiftCardResponseProduct](docs/ReloadlyGiftCardResponseProduct.md)
 - [ReloadlyGiftCardResponseProductBrand](docs/ReloadlyGiftCardResponseProductBrand.md)
 - [SkyfireUser](docs/SkyfireUser.md)
 - [UpdateWalletRequest](docs/UpdateWalletRequest.md)
 - [UserType](docs/UserType.md)
 - [Wallet](docs/Wallet.md)
 - [WalletBalance](docs/WalletBalance.md)
 - [WalletBalanceClaims](docs/WalletBalanceClaims.md)
 - [WalletBalanceEscrow](docs/WalletBalanceEscrow.md)
 - [WalletBalanceNative](docs/WalletBalanceNative.md)
 - [WalletBalanceOnchain](docs/WalletBalanceOnchain.md)
 - [WalletList](docs/WalletList.md)
 - [WalletType](docs/WalletType.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>
### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: skyfire-api-key
- **Location**: HTTP header


## Author

support@skyfire.xyz


